{interactive slug="arrows" type="whole-page" text="true"}

The text.

{interactive end}

And some more text again.

{interactive slug="flying-boxes" type="whole-page" text="true"}

the text.

{interactive end}

Aaaaaaaaaaaaaaaannnnnd here's some more.
